#!/bin/sh

KOLAB_HOME=~kolab
BUILD_LIST="${KOLAB_HOME}/package-build.info"
BUILD_HOME="${KOLAB_HOME}/RPM/SRC"
RPM_HOME="${KOLAB_HOME}/RPM/PKG"
LOGDIR="${KOLAB_HOME}/.build.logs"
RPM="${KOLAB_HOME}/bin/rpm"

[ -d "${LOGDIR}" ] || {
	mkdir -p "${LOGDIR}" && echo "Log directory created @ '${LOGDIR}'"
}

[ -d "${LOGDIR}" ] || {
	echo "Could not create log directory @ '${LOGDIR}'"
	exit 1
}

build_and_install_package ()
{
	pkg="${1}"
	[ -z "${pkg}" ] && {
		echo "error: no package name given to build_package"
		return 1
	}
	spec="${2}"
	build="${3}"
	flags="${4}"

	(
		"${RPM}" -q "${pkg}" >/dev/null 2>&1 && exit 0
		cd "${BUILD_HOME}/${pkg}" || exit -1
		LOG="${LOGDIR}/${pkg}.log"
		echo -n "Building '${pkg}': ${RPM} -b${build} \"${spec}\" ${flags} ... "
		if eval "\"${RPM}\"" -b${build} "${spec}" ${flags} >"${LOG}" 2>&1
		then
			echo "Built OK"
			if sudo "${RPM}" -Uhv ${RPM_HOME}/${pkg}-*-kol.rpm
			then
				exit 0
			fi
		fi
		echo "Failed ( Status = ${?}, Error log @ '${LOG}' )!"
		exit 1
	) || return 1
	return 0
}

echo "Processing from build list @ '${BUILD_LIST}'"
cat "${BUILD_LIST}" | sed -e 's/^[[:space:]]*#.*//g' -e 's/^[[:space:]]*$//g' | grep -v '^$' | while read pkg spec build flags
do 
	build_and_install_package "${pkg}" "${spec}" "${build}" "${flags}" || {
		echo "Failed installing '${pkg}'"
		exit 1
	}
done
