#!/bin/sh

SH=$(which sh)
SU=$(which su)
CP=$(which cp)
CHMOD=$(which chmod)
TEE=$(which tee)

USER="${1}"
[ ${#} -ne 1 -o -z "${USER}" ] && {
	echo "usage: ${0} common-user-name"
	echo "       The user name given will be the one used ONLY for building the OpenPackage bootstrap environment"
	exit 1
}

ID=$(id -u)
[ -z "${ID}" ] && {
	echo "Cannot identify the active user, aborting"
	exit 1
}

[ ${ID} -ne 0 ] && {
	echo "Must be run as root"
	exit 1
}

KOLAB_USER=kolab
KOLAB_GROUP=kolab
KOLAB_HOME=/kolab
KRPM="${KOLAB_HOME}/bin/rpm"

BASE="${PWD}"
INSTALL_LOG="kolab-install.log"

# Build the OpenPackage environment script
${SU} - ${USER} -c ${SH} <<EOF || exit 1
cd ${BASE} || exit 1
[ -w . ] || {
	echo "User '${USER}' can't write to '${BASE}'"
	exit 1
}
> ${INSTALL_LOG} || exit 1
${SH} openpkg-1.2.0-1.2.0.src.sh --prefix=${KOLAB_HOME} --user=${KOLAB_USER} --group=${KOLAB_GROUP} 2>&1 | ${TEE} ${INSTALL_LOG} || exit 1
EOF

# Install the OpenPackage environment
${SH} ${BASE}/openpkg-1.2.0-1.2.0.ix86-linux2.4-kol.sh || exit 1

# Install the sources for the packages that must be built
${SU} - ${KOLAB_USER} -c "cd ${BASE} && ${KRPM} -ivh *.src.rpm" || exit 1

# Install the build scripts
${CP} ${BASE}/build.sh ${BASE}/package-build.info ${KOLAB_HOME} || exit 1

# Run the build process
${SU} - ${KOLAB_USER} -c "cd && ./build.sh" || exit 1

